Application class

Application metadata for firmware-distributed builds.

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

Application({required String appId, required String appName, required String userId, required String description, String? iconUrl, required List<String> tags, required List<Version> versions})
Application.fromJson(Map<String, dynamic> json)
factory

Properties

appId String
getter/setter pair
appName String
getter/setter pair
description String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
iconUrl String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>
getter/setter pair
userId String
getter/setter pair
versions List<Version>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited