FrequencyPlayer class abstract

Implementers

Constructors

FrequencyPlayer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportedFrequencyPlayerWaveTypes List<WaveType>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
playFrequency(WaveType waveType, {double frequency = 440.0, double loudness = 1}) Future<void>
waveType The type of waveform to play. frequency The frequency of the sound in Hz. loudness The loudness of the sound, should be a value between 0 and 1.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited