HeartRateVariabilitySensor class

Inheritance

Constructors

HeartRateVariabilitySensor({List<SensorConfiguration<SensorConfigurationValue>> relatedConfigurations = const [], required Stream<List<int>> rrIntervalsMsStream})

Properties

axisCount int
The number of axes the sensor has.
no setteroverride
axisNames List<String>
The name of the different axes of the sensor.
no setteroverride
axisUnits List<String>
The units of the different axes of the sensor.
no setteroverride
chartTitle String
The title of the chart that displays the sensor data.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
relatedConfigurations List<SensorConfiguration<SensorConfigurationValue>>
A list of related sensor configurations that are used to modify the sensor's behavior.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensorName String
The name of the sensor, used for identification and display purposes.
finalinherited
sensorStream Stream<HeartRateVariabilitySensorValue>
A stream of sensor values that emits new values as they are received. In order to use this stream, the sensor must be started using the relatedConfigurations.
no setteroverride
shortChartTitle String
A shorter version of the chart title, used for compact displays.
finalinherited
timestampExponent int
The exponent of the timestamp value. 0 for seconds, -3 for milliseconds, -6 for microseconds, etc.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited