sensorStream property

  1. @override
Stream<HeartRateVariabilitySensorValue> get sensorStream
override

A stream of sensor values that emits new values as they are received. In order to use this stream, the sensor must be started using the relatedConfigurations.

Implementation

@override
Stream<HeartRateVariabilitySensorValue> get sensorStream =>
    _streamController.stream;