Recorder class

Constructors

Recorder({required List<String> columns})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start({required String filepath, required Stream<SensorValue> inputStream, bool append = false}) Future<File>
Starts the recording process. It writes sensor data to a file at the specified filepath. If append is true, it appends to the existing file; otherwise, it creates a new file. Returns the File object for the recorded file. Throws an exception if recording is already in progress.
stop() → void
Stops the recording process.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited