Sensor<SV extends SensorValue> class abstract

A base class for sensors that provides common properties and methods. It is designed to be extended by specific sensor implementations.

This class defines the basic structure of a sensor, including its name, chart title, short chart title, timestamp exponent, and related configurations. It also provides a stream of sensor values and methods to retrieve axis names and units.

Implementers

Constructors

Sensor({required String sensorName, required String chartTitle, required String shortChartTitle, int timestampExponent = -3, List<SensorConfiguration<SensorConfigurationValue>> relatedConfigurations = const []})
const

Properties

axisCount int
The number of axes the sensor has.
no setter
axisNames List<String>
The name of the different axes of the sensor.
no setter
axisUnits List<String>
The units of the different axes of the sensor.
no setter
chartTitle String
The title of the chart that displays the sensor data.
final
hashCode int
The hash code for this object.
no setterinherited
relatedConfigurations List<SensorConfiguration<SensorConfigurationValue>>
A list of related sensor configurations that are used to modify the sensor's behavior.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensorName String
The name of the sensor, used for identification and display purposes.
final
sensorStream Stream<SV>
A stream of sensor values that emits new values as they are received. In order to use this stream, the sensor must be started using the relatedConfigurations.
no setter
shortChartTitle String
A shorter version of the chart title, used for compact displays.
final
timestampExponent int
The exponent of the timestamp value. 0 for seconds, -3 for milliseconds, -6 for microseconds, etc.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited