relatedConfigurations property
A list of related sensor configurations that are used to modify the sensor's behavior.
Implementation
final List<SensorConfiguration> relatedConfigurations;
A list of related sensor configurations that are used to modify the sensor's behavior.
final List<SensorConfiguration> relatedConfigurations;