SensorConfigurationValue class

A value for a sensor configuration. This class is designed to be extended by specific sensor configuration value implementations. It represents a single possible behavior for a sensor configuration.

Implementers

Constructors

SensorConfigurationValue({required String key})

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
The key of the configuration value. This key is used to identify the configuration value in the UI or logs.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited