SensorFrequencyConfiguration<SFC extends SensorFrequencyConfigurationValue> class abstract

Inheritance
Implementers

Constructors

SensorFrequencyConfiguration({required String name, required List<SFC> values, SFC? offValue})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Name of the configuration This is used to identify the configuration in the UI or logs.
finalinherited
offValue → SFC?
Optional value that indicates the off state of the sensor.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unit String?
Optional unit of the sensor configuration. For example, "Hz" for frequency when dealing with frequency configurations.
finalinherited
values List<SFC>
A list of possible values for the sensor behavior.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setConfiguration(SFC configuration) → void
Sets the configuration to the specified value. This method should be implemented by subclasses to apply the configuration. It is expected that the implementation will handle the specifics of how the configuration is applied.
inherited
setFrequencyBestEffort(int targetFrequencyHz) → SFC?
Sets the frequency close to targetFrequencyHz. Either the next biggest or the maximum frequency.
setMaximumFrequency() → SFC?
Sets the maximum frequency.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited