SensorFrequencyConfigurationValue class

Inheritance
Implementers

Constructors

SensorFrequencyConfigurationValue({required double frequencyHz, String? key})

Properties

frequencyHz double
final
hashCode int
The hash code for this object.
no setteroverride
key String
The key of the configuration value. This key is used to identify the configuration value in the UI or logs.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override