SensorManager class abstract

A device that manages a collection of sensors.

Implementers

Constructors

SensorManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensors List<Sensor<SensorValue>>
The sensors managed by this device. This is a read-only list of sensors.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited