UploadProgress class
- Inheritance
-
- Object
- UpdateEvent
- UploadState
- UploadProgress
Constructors
- UploadProgress({required String stage, required int progress, required int imageNumber})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageNumber → int
-
final
- progress → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited