BleGattManager class abstract
An interface for managing Bluetooth Low Energy (BLE) GATT operations.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disconnect(
String deviceId) → Future< void> - Disconnects from a device.
-
hasCharacteristic(
{required String deviceId, required String serviceId, required String characteristicId}) → Future< bool> -
hasService(
{required String deviceId, required String serviceId}) → Future< bool> - Checks if a specific service is available on the connected device.
-
isConnected(
String deviceId) → bool - Check if a device is connected.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
{required String deviceId, required String serviceId, required String characteristicId}) → Future< List< int> > - Reads data from a specific characteristic of the connected device.
-
subscribe(
{required String deviceId, required String serviceId, required String characteristicId}) → Stream< List< int> > - Subscribes to a specific characteristic of the connected device.
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
{required String deviceId, required String serviceId, required String characteristicId, required List< int> byteData}) → Future<void> - Writes byte data to a specific characteristic of a device.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited