ConfigurableSensorConfigurationValue class abstract
A base class for sensor configuration values that can be configured with options. This class extends SensorConfigurationValue and adds a set of options that can be applied to the configuration value. It is designed to be used with ConfigurableSensorConfiguration.
- Inheritance
-
- Object
- SensorConfigurationValue
- ConfigurableSensorConfigurationValue
- Implementers
Constructors
-
ConfigurableSensorConfigurationValue({required String key, Set<
SensorConfigurationOption> options = const {}})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- key → String
-
The key of the configuration value.
This key is used to identify the configuration value in the UI or logs.
finalinherited
-
options
→ Set<
SensorConfigurationOption> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
withoutOptions(
) → ConfigurableSensorConfigurationValue
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override