CosinussOne class
Inheritance
Implemented types
Methods
addDisconnectListener (VoidCallback listener )
→ void
inherited
capabilityAvailable <T > ()
→ Stream <void >
inherited
disconnect ()
→ Future <void >
override
getCapability <T > ()
→ T?
Gets a specific capability of the wearable.
Returns null if the capability is not supported by this wearable.
inherited
getWearableIconPath ({bool darkmode = false , WearableIconVariant variant = WearableIconVariant.single })
→ String ?
Gets path to an icon representing the wearable.
Preferred type is SVG.
Needs to be added to the asset section of the pubspec.yaml file.
When setting the path here, keep in mind it's a lib
('packages/open_earable_flutter/assets/...').
override
hasCapability <T > ()
→ bool
Checks if the wearable has a specific capability.
inherited
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readBatteryPercentage ()
→ Future <int >
Reads the battery percentage of the device.
The value is between 0 and 100.
override
registerCapability <T > (T capability )
→ void
Registers a specific capability for the wearable.
Throws a StateError if the capability is already registered.
inherited
requireCapability <T > ()
→ T
Gets a specific capability of the wearable, throwing a StateError if not supported.
inherited
toString ()
→ String
A string representation of this object.
inherited
open_earable_flutter 2.3.4