MultiImageFirmwareUpdateRequest class
- Inheritance
-
- Object
- FirmwareUpdateRequest
- MultiImageFirmwareUpdateRequest
Constructors
-
MultiImageFirmwareUpdateRequest({Uint8List? zipFile, List<
Image> ? firmwareImages, SelectedPeripheral? peripheral, SelectedFirmware? firmware})
Properties
- firmware ↔ SelectedFirmware?
-
getter/setter pairinherited
-
firmwareImages
↔ List<
Image> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- peripheral ↔ SelectedPeripheral?
-
getter/setter pairinherited
- remoteFirmware → RemoteFirmware?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- zipFile ↔ Uint8List?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited