SensorConfigurationValue class
A value for a sensor configuration. This class is designed to be extended by specific sensor configuration value implementations. It represents a single possible behavior for a sensor configuration.
Constructors
- SensorConfigurationValue({required String key})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited