SensorFrequencyConfiguration<SFC extends SensorFrequencyConfigurationValue > class
abstract
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
name
→ String
Name of the configuration
This is used to identify the configuration in the UI or logs.
final inherited
offValue
→ SFC?
Optional value that indicates the off state of the sensor.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
unit
→ String ?
Optional unit of the sensor configuration.
For example, "Hz" for frequency when dealing with frequency configurations.
final inherited
values
→ List <SFC >
A list of possible values for the sensor behavior.
final inherited
Methods
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setConfiguration (SFC configuration )
→ void
Sets the configuration to the specified value.
This method should be implemented by subclasses to apply the configuration.
It is expected that the implementation will handle the specifics of how the configuration is applied.
inherited
setFrequencyBestEffort (int targetFrequencyHz )
→ SFC?
Sets the frequency close to targetFrequencyHz.
Either the next biggest or the maximum frequency.
setMaximumFrequency ()
→ SFC?
Sets the maximum frequency.
toString ()
→ String
A string representation of this object.
override
open_earable_flutter 2.3.8